import React from 'react'

import { DropzoneState, useDropzone } from 'react-dropzone'
import { FileWithName } from 'src/models'

export const MAX_FILE_SIZE = 250 * 1024 * 1024
export const SIZE_TOO_LARGE = 'size-too-large'

export const useAddFormalizations = ({}): {
  dropzoneState: DropzoneState
  formalizations: FileWithName[]
  handleRemoveFormalization: (index: number) => void
} => {
  const [formalizations, setFormalizations] = React.useState<FileWithName[]>([])

  const onDrop = React.useCallback((acceptedFiles: File[]) => {
    setFormalizations((currentFormalizations) => {
      const res = acceptedFiles.map(
        (f) =>
          ({
            file: f,
            name: f.name.split('.')[0] ?? f.name,
          } as FileWithName)
      )
      return [...currentFormalizations, ...res]
    })
  }, [])

  const dropzoneState = useDropzone({
    onDrop,
    noDrag: true,
    validator: (file) => {
      if (file.size > MAX_FILE_SIZE) {
        return {
          code: SIZE_TOO_LARGE,
          message: `Maximo ${MAX_FILE_SIZE} MB.`,
        }
      }
      return null
    },
  })

  const handleRemoveFormalization = (index: number) => {
    const formalizationsCopy = [...formalizations]
    formalizationsCopy.splice(index, 1)
    setFormalizations(formalizationsCopy)
  }

  return { dropzoneState, formalizations, handleRemoveFormalization }
}
